==> eff_3-7.0.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"all","t":"all","d":"","k":"static","x":""},
{"l":"org/atnos/eff.html#","e":false,"i":"","n":"org.atnos.eff","t":"org.atnos.eff","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax.html#","e":false,"i":"","n":"org.atnos.eff.syntax","t":"org.atnos.eff.syntax","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax/all$.html#","e":false,"i":"","n":"all","t":"all extends all","d":"org.atnos.eff.syntax","k":"object","x":""},
{"l":"org/atnos/eff/syntax/all.html#","e":false,"i":"","n":"all","t":"all extends eval, option, either, validate, error, reader, writer, choose, list, state, safe, batch, memo, eff","d":"org.atnos.eff.syntax","k":"trait","x":""},
{"l":"org/atnos/eff/SubscribeEffect$.html#","e":false,"i":"","n":"SubscribeEffect","t":"SubscribeEffect","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/SubscribeEffect$.html#Callback-0","e":false,"i":"","n":"Callback","t":"Callback[A] = Either[Throwable, A] => Unit","d":"org.atnos.eff.SubscribeEffect","k":"type","x":""},
{"l":"org/atnos/eff/SubscribeEffect$.html#FS-0","e":false,"i":"","n":"FS","t":"FS = Fx1[Subscribe]","d":"org.atnos.eff.SubscribeEffect","k":"type","x":""},
{"l":"org/atnos/eff/SubscribeEffect$.html#_subscribe-0","e":false,"i":"","n":"_subscribe","t":"_subscribe[R] = MemberIn[Subscribe, R]","d":"org.atnos.eff.SubscribeEffect","k":"type","x":""},
{"l":"org/atnos/eff/SubscribeEffect$.html#memoize-c3e","e":false,"i":"","n":"memoize","t":"memoize[K <: AnyRef, A](key: K, sequenceKey: Int, cache: Cache, e: Eff[FS, A]): Eff[FS, A]","d":"org.atnos.eff.SubscribeEffect","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$.html#memoizeSubscribe-eaa","e":false,"i":"","n":"memoizeSubscribe","t":"memoizeSubscribe[A](key: AnyRef, cache: Cache, e: Subscribe[A]): Subscribe[A]","d":"org.atnos.eff.SubscribeEffect","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$.html#subscribeAttempt-fffffa51","e":false,"i":"","n":"subscribeAttempt","t":"subscribeAttempt[A](e: Eff[FS, A]): Eff[FS, ThrowableEither[A]]","d":"org.atnos.eff.SubscribeEffect","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$.html#subscribeToAttemptedSubscribe-0","e":false,"i":"","n":"subscribeToAttemptedSubscribe","t":"subscribeToAttemptedSubscribe: FunctionK[Subscribe, AttemptedSubscribe]","d":"org.atnos.eff.SubscribeEffect","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$AttemptedSubscribe.html#","e":false,"i":"","n":"AttemptedSubscribe","t":"AttemptedSubscribe[A](subscribe: (() => Either[Throwable, A]) => Unit, memoizeKey: Option[(AnyRef, Cache)]) extends Subscribe[Either[Throwable, A]]","d":"org.atnos.eff.SubscribeEffect","k":"class","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$AttemptedSubscribe.html#apply-c9d","e":false,"i":"","n":"apply","t":"apply(cb: () => Either[Throwable, A]): Unit","d":"org.atnos.eff.SubscribeEffect.AttemptedSubscribe","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$AttemptedSubscribe.html#unmemoize-0","e":false,"i":"","n":"unmemoize","t":"unmemoize: AttemptedSubscribe[A]","d":"org.atnos.eff.SubscribeEffect.AttemptedSubscribe","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$SimpleSubscribe.html#","e":false,"i":"","n":"SimpleSubscribe","t":"SimpleSubscribe[A](subscribe: (() => A) => Unit, memoizeKey: Option[(AnyRef, Cache)]) extends Subscribe[A]","d":"org.atnos.eff.SubscribeEffect","k":"class","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$SimpleSubscribe.html#apply-c9d","e":false,"i":"","n":"apply","t":"apply(cb: () => A): Unit","d":"org.atnos.eff.SubscribeEffect.SimpleSubscribe","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$SimpleSubscribe.html#unmemoize-0","e":false,"i":"","n":"unmemoize","t":"unmemoize: Subscribe[A]","d":"org.atnos.eff.SubscribeEffect.SimpleSubscribe","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$Subscribe.html#","e":false,"i":"","n":"Subscribe","t":"Subscribe[A] extends (() => A) => Unit","d":"org.atnos.eff.SubscribeEffect","k":"trait","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$Subscribe.html#memoizeKey-0","e":false,"i":"","n":"memoizeKey","t":"memoizeKey: Option[(AnyRef, Cache)]","d":"org.atnos.eff.SubscribeEffect.Subscribe","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$Subscribe.html#unmemoize-0","e":false,"i":"","n":"unmemoize","t":"unmemoize: Subscribe[A]","d":"org.atnos.eff.SubscribeEffect.Subscribe","k":"def","x":""},
{"l":"org/atnos/eff/all$.html#","e":false,"i":"","n":"all","t":"all extends ReaderEffect, WriterEffect, StateEffect, EvalEffect, OptionEffect, ListEffect, EitherEffect, ValidateEffect, ChooseEffect, SafeEffect, MemoEffect, Batch, EffInterpretation, EffCreation, EffImplicits","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/create$.html#","e":false,"i":"","n":"create","t":"create extends ReaderCreation, WriterCreation, StateCreation, EvalCreation, OptionCreation, ListCreation, EitherCreation, ValidateCreation, ChooseCreation, FutureCreation, MemoCreation, EffCreation, SafeCreation","d":"org.atnos.eff","k":"object","x":""}];

==> eff_3-7.0.5-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"all","t":"all","d":"","k":"static","x":""},
{"l":"org/atnos/eff.html#","e":false,"i":"","n":"org.atnos.eff","t":"org.atnos.eff","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax.html#","e":false,"i":"","n":"org.atnos.eff.syntax","t":"org.atnos.eff.syntax","d":"","k":"package","x":""},
{"l":"org/atnos/eff/syntax/all$.html#","e":false,"i":"","n":"all","t":"all extends all","d":"org.atnos.eff.syntax","k":"object","x":""},
{"l":"org/atnos/eff/syntax/all.html#","e":false,"i":"","n":"all","t":"all extends eval, option, either, validate, error, reader, writer, choose, list, state, safe, batch, memo, eff","d":"org.atnos.eff.syntax","k":"trait","x":""},
{"l":"org/atnos/eff/SubscribeEffect$.html#","e":false,"i":"","n":"SubscribeEffect","t":"SubscribeEffect","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/SubscribeEffect$.html#Callback-0","e":false,"i":"","n":"Callback","t":"Callback[A] = (Either[Throwable, A]) => Unit","d":"org.atnos.eff.SubscribeEffect","k":"type","x":""},
{"l":"org/atnos/eff/SubscribeEffect$.html#FS-0","e":false,"i":"","n":"FS","t":"FS = Fx1[Subscribe]","d":"org.atnos.eff.SubscribeEffect","k":"type","x":""},
{"l":"org/atnos/eff/SubscribeEffect$.html#_subscribe-0","e":false,"i":"","n":"_subscribe","t":"_subscribe[R] = MemberIn[Subscribe, R]","d":"org.atnos.eff.SubscribeEffect","k":"type","x":""},
{"l":"org/atnos/eff/SubscribeEffect$.html#memoize-c3e","e":false,"i":"","n":"memoize","t":"memoize[K <: AnyRef, A](key: K, sequenceKey: Int, cache: Cache, e: Eff[FS, A]): Eff[FS, A]","d":"org.atnos.eff.SubscribeEffect","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$.html#memoizeSubscribe-eaa","e":false,"i":"","n":"memoizeSubscribe","t":"memoizeSubscribe[A](key: AnyRef, cache: Cache, e: Subscribe[A]): Subscribe[A]","d":"org.atnos.eff.SubscribeEffect","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$.html#subscribeAttempt-fffffa51","e":false,"i":"","n":"subscribeAttempt","t":"subscribeAttempt[A](e: Eff[FS, A]): Eff[FS, ThrowableEither[A]]","d":"org.atnos.eff.SubscribeEffect","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$.html#subscribeToAttemptedSubscribe-0","e":false,"i":"","n":"subscribeToAttemptedSubscribe","t":"subscribeToAttemptedSubscribe: FunctionK[Subscribe, AttemptedSubscribe]","d":"org.atnos.eff.SubscribeEffect","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$AttemptedSubscribe.html#","e":false,"i":"","n":"AttemptedSubscribe","t":"AttemptedSubscribe[A](subscribe: (() => Either[Throwable, A]) => Unit, memoizeKey: Option[(AnyRef, Cache)]) extends Subscribe[Either[Throwable, A]]","d":"org.atnos.eff.SubscribeEffect","k":"class","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$AttemptedSubscribe.html#apply-c9d","e":false,"i":"","n":"apply","t":"apply(cb: () => Either[Throwable, A]): Unit","d":"org.atnos.eff.SubscribeEffect.AttemptedSubscribe","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$AttemptedSubscribe.html#unmemoize-0","e":false,"i":"","n":"unmemoize","t":"unmemoize: AttemptedSubscribe[A]","d":"org.atnos.eff.SubscribeEffect.AttemptedSubscribe","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$SimpleSubscribe.html#","e":false,"i":"","n":"SimpleSubscribe","t":"SimpleSubscribe[A](subscribe: (() => A) => Unit, memoizeKey: Option[(AnyRef, Cache)]) extends Subscribe[A]","d":"org.atnos.eff.SubscribeEffect","k":"class","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$SimpleSubscribe.html#apply-c9d","e":false,"i":"","n":"apply","t":"apply(cb: () => A): Unit","d":"org.atnos.eff.SubscribeEffect.SimpleSubscribe","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$SimpleSubscribe.html#unmemoize-0","e":false,"i":"","n":"unmemoize","t":"unmemoize: Subscribe[A]","d":"org.atnos.eff.SubscribeEffect.SimpleSubscribe","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$Subscribe.html#","e":false,"i":"","n":"Subscribe","t":"Subscribe[A] extends (() => A) => Unit","d":"org.atnos.eff.SubscribeEffect","k":"trait","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$Subscribe.html#memoizeKey-0","e":false,"i":"","n":"memoizeKey","t":"memoizeKey: Option[(AnyRef, Cache)]","d":"org.atnos.eff.SubscribeEffect.Subscribe","k":"def","x":""},
{"l":"org/atnos/eff/SubscribeEffect$$Subscribe.html#unmemoize-0","e":false,"i":"","n":"unmemoize","t":"unmemoize: Subscribe[A]","d":"org.atnos.eff.SubscribeEffect.Subscribe","k":"def","x":""},
{"l":"org/atnos/eff/all$.html#","e":false,"i":"","n":"all","t":"all extends ReaderEffect, WriterEffect, StateEffect, EvalEffect, OptionEffect, ListEffect, EitherEffect, ValidateEffect, ChooseEffect, SafeEffect, MemoEffect, Batch, EffInterpretation, EffCreation, EffImplicits","d":"org.atnos.eff","k":"object","x":""},
{"l":"org/atnos/eff/create$.html#","e":false,"i":"","n":"create","t":"create extends ReaderCreation, WriterCreation, StateCreation, EvalCreation, OptionCreation, ListCreation, EitherCreation, ValidateCreation, ChooseCreation, FutureCreation, MemoCreation, EffCreation, SafeCreation","d":"org.atnos.eff","k":"object","x":""}];
